# Table of Contents

- [using-graphql-with-python](<./using-graphql-with-python.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Using GraphQL with Python](<./Using-GraphQL-with-Python.md>)
  - [Overview](<./Using-GraphQL-with-Python/Overview.md>)
  - [Prerequisites](<./Using-GraphQL-with-Python/Prerequisites.md>)
  - [Step 1: Create a Python Project](<./Using-GraphQL-with-Python/Step-1-Create-a-Python-Project.md>)
  - [Step 2: Create and Run a Python GraphQL Query Script](<./Using-GraphQL-with-Python/Step-2-Create-and-Run-a-Python-GraphQL-Query-Script.md>)
  - [Step 3: Create and Run a Python GraphQL Mutation Script](<./Using-GraphQL-with-Python/Step-3-Create-and-Run-a-Python-GraphQL-Mutation-Script.md>)
  - [Step 4: Validate the Mutation Script](<./Using-GraphQL-with-Python/Step-4-Validate-the-Mutation-Script.md>)
  - [Summary](<./Using-GraphQL-with-Python/Summary.md>)
